package net.vtstar.zhongtong.avi.gateway.painting.job;

import com.alibaba.fastjson.JSONObject;
import io.netty.channel.ConnectTimeoutException;
import lombok.extern.slf4j.Slf4j;
import net.vtstar.protocol.modbus.tcp.netty.utils.NettyUtils;
import net.vtstar.protocol.modbus.tcp.netty.utils.PoolKey;
import net.vtstar.scada.base.equipmgt.domain.EquipCommunication;
import net.vtstar.scada.base.equipmgt.domain.EquipDataChannel;
import net.vtstar.scada.base.equipmgt.domain.EquipDataTemplate;
import net.vtstar.scada.base.equipmgt.domain.EquipDataTemplateItem;
import net.vtstar.scada.base.equipmgt.service.EquipInfoService;
import net.vtstar.scada.base.gather.job.GatherJob;
import net.vtstar.scada.base.global.exception.EquipConnectException;
import net.vtstar.scada.base.global.service.ModbusService;
import net.vtstar.zhongtong.avi.gateway.painting.domain.SprayBoothMachine;
import net.vtstar.zhongtong.avi.gateway.painting.mapper.SprayBoothMapper;
import org.quartz.JobExecutionContext;
import org.quartz.JobExecutionException;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.springframework.util.CollectionUtils;

import java.util.Date;
import java.util.List;

/**
 * 新加喷漆房数据采集JOB
 */
@Slf4j
@Component
public class SprayBoothMachineJob extends GatherJob {

    @Autowired
    private EquipInfoService equipInfoService;
    @Autowired
    private ModbusService modbusService;

    @Autowired
    private SprayBoothMapper mapper;

    @Override
    protected void executeInternal(JobExecutionContext context) throws JobExecutionException {
        List<EquipCommunication> commList = equipInfoService.getCommunicationList("喷涂房温室度", 1);
        if (CollectionUtils.isEmpty(commList)) {
            return;
        }
        SprayBoothMachine equipmentData = new SprayBoothMachine();
        boolean hasConnError = false;
        for (EquipCommunication comm : commList) {
            EquipDataChannel dataChannel = comm.getDataChannel();
            String ip = dataChannel.getIp();
            Integer port = dataChannel.getPort();
            PoolKey poolKey = NettyUtils.wrapPoolKey(ip, port);
            EquipDataTemplate template = comm.getDataTemplate();
            if (template == null) {
                log.error("无法获取设备的数据模板，设备编号：{}", dataChannel.getEquipCode());
                continue;
            }

            List<EquipDataTemplateItem> templateItemList = template.getTemplateItemList();
            if (CollectionUtils.isEmpty(templateItemList)) {
                log.error("无法获取数据模板的条目，设备编号：{},模板名称：{}", dataChannel.getEquipCode(), template.getName());
                continue;
            }
            try {
                modbusService.getMachineAllValue(equipmentData, templateItemList, poolKey, dataChannel.getNo(), this);
                log.info("设备:{}, 采集模板:{}", equipmentData.getEquipCode(), JSONObject.toJSONString(templateItemList));
            } catch (EquipConnectException e) {
                log.error("设备连接异常:", e);
                hasConnError = true;
                break;
            } catch (ConnectTimeoutException e) {
                log.error("设备连接超时异常:", e);
                hasConnError = true;
                break;
            }catch (IllegalStateException e){
                log.error(e.getMessage());
                hasConnError = true;
                break;
            }catch (Exception e) {
                log.error(e.getMessage());
                hasConnError = true;
            }
        }
        if (hasConnError){
            log.error("获取设备：喷漆房 的采集数据失败!{}", JSONObject.toJSONString(equipmentData));
        }else{
            equipmentData.setEquipCode("喷漆房");
            equipmentData.setEquipFactory("");
            equipmentData.setCreateTime(new Date());
            mapper.insert(equipmentData);
        }
    }
}
