package net.vtstar.zhongtong.avi.gateway.parts.job;

import io.netty.util.internal.StringUtil;
import lombok.extern.slf4j.Slf4j;
import net.vtstar.scada.base.equipmgt.domain.Enum.EquipStatusEnum;
import net.vtstar.scada.base.gather.domain.EquipmentData;
import net.vtstar.scada.base.gather.job.GatherJob;
import net.vtstar.zhongtong.avi.gateway.parts.domain.DustingLineMachine;
import net.vtstar.zhongtong.avi.gateway.parts.domain.WeldingRobotWorkstationMachine;
import org.quartz.JobExecutionContext;
import org.quartz.JobExecutionException;
import org.springframework.stereotype.Component;

import java.util.Date;

/**
 * 焊接机器人工作站数据采集JOB
 */
@Slf4j
@Component
public class WeldingRobotWorkMachineJob extends GatherJob {

    private static final String NAME = "WELDING_ROBOT_WORKSTATION";

    @Override
    protected void executeInternal(JobExecutionContext context) throws JobExecutionException {

        super.gatherByModbus(NAME, WeldingRobotWorkstationMachine.class);
    }

    @Override
    public boolean handleObject(EquipmentData equipmentData) {
        WeldingRobotWorkstationMachine data = (WeldingRobotWorkstationMachine) equipmentData;
        String state = data.getStatus();
        if (state == null || "0".equals(state)) {
            return false;
        }
        equipmentData.setEquipStatus(EquipStatusEnum.RUN);
        return true;
    }

    @Override
    public Object handleValue(String fieldName, Object value) {
        //TODO: 对采集数据进行解析
        if("turnOnTime".equals(fieldName) && null != value){
            return null;
        }
        return value;
    }

    @Override
    protected void postHandle(EquipmentData equipmentData) {
        ((DustingLineMachine)equipmentData).setCreateTime(new Date());
    }
}
